@@ -4,7 +4,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2016	PgPool Global Development Group
+ * Copyright (c) 2003-2018	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -36,19 +36,19 @@
 #include "utils/getopt_long.h"
 #endif
 
-const char* progname = NULL;
-const char * get_progname(const char *argv0);
-char *last_dir_separator(const char *filename);
+const char *progname = NULL;
+const char *get_progname(const char *argv0);
+char	   *last_dir_separator(const char *filename);
 
 static void usage(void);
 static inline bool app_require_nodeID(void);
-static void output_watchdog_info_result(PCPResultInfo* pcpResInfo, bool verbose);
-static void output_procinfo_result(PCPResultInfo* pcpResInfo, bool all, bool verbose);
-static void output_proccount_result(PCPResultInfo* pcpResInfo, bool verbose);
-static void output_poolstatus_result(PCPResultInfo* pcpResInfo, bool verbose);
-static void output_nodeinfo_result(PCPResultInfo* pcpResInfo, bool verbose);
-static void output_nodecount_result(PCPResultInfo* pcpResInfo, bool verbose);
-static char* backend_status_to_string(BackendInfo *bi);
+static void output_watchdog_info_result(PCPResultInfo * pcpResInfo, bool verbose);
+static void output_procinfo_result(PCPResultInfo * pcpResInfo, bool all, bool verbose);
+static void output_proccount_result(PCPResultInfo * pcpResInfo, bool verbose);
+static void output_poolstatus_result(PCPResultInfo * pcpResInfo, bool verbose);
+static void output_nodeinfo_result(PCPResultInfo * pcpResInfo, bool verbose);
+static void output_nodecount_result(PCPResultInfo * pcpResInfo, bool verbose);
+static char *backend_status_to_string(BackendInfo * bi);
 
 typedef enum
 {
@@ -64,53 +64,53 @@ typedef enum
 	PCP_STOP_PGPOOL,
 	PCP_WATCHDOG_INFO,
 	UNKNOWN,
-} PCP_UTILITIES;
+}			PCP_UTILITIES;
 
 struct AppTypes
 {
 	const char *app_name;
 	PCP_UTILITIES app_type;
-	const char* allowed_options;
-	const char* description;
+	const char *allowed_options;
+	const char *description;
 };
 
 struct AppTypes AllAppTypes[] =
-	{
-		{"pcp_attach_node", PCP_ATTACH_NODE,"n:h:p:U:wWvd","attach a node from pgpool-II"},
-		{"pcp_detach_node", PCP_DETACH_NODE,"n:h:p:U:gwWvd","detach a node from pgpool-II"},
-		{"pcp_node_count", PCP_NODE_COUNT,"h:p:U:wWvd","display the total number of nodes under pgpool-II's control"},
-		{"pcp_node_info", PCP_NODE_INFO,"n:h:p:U:wWvd", "display a pgpool-II node's information"},
-		{"pcp_pool_status", PCP_POOL_STATUS,"h:p:U:wWvd", "display pgpool configuration and status"},
-		{"pcp_proc_count", PCP_PROC_COUNT,"h:p:U:wWvd", "display the list of pgpool-II child process PIDs"},
-		{"pcp_proc_info", PCP_PROC_INFO,"h:p:P:U:awWvd","display a pgpool-II child process' information"},
-		{"pcp_promote_node", PCP_PROMOTE_NODE,"n:h:p:U:gwWvd", "promote a node as new master from pgpool-II"},
-		{"pcp_recovery_node", PCP_RECOVERY_NODE,"n:h:p:U:wWvd","recover a node"},
-		{"pcp_stop_pgpool", PCP_STOP_PGPOOL,"m:h:p:U:wWvd", "terminate pgpool-II"},
-		{"pcp_watchdog_info", PCP_WATCHDOG_INFO,"n:h:p:U:wWvd", "display a pgpool-II watchdog's information"},
-		{NULL, UNKNOWN,NULL,NULL},
-	};
-struct AppTypes* current_app_type;
+{
+	{"pcp_attach_node", PCP_ATTACH_NODE, "n:h:p:U:wWvd", "attach a node from pgpool-II"},
+	{"pcp_detach_node", PCP_DETACH_NODE, "n:h:p:U:gwWvd", "detach a node from pgpool-II"},
+	{"pcp_node_count", PCP_NODE_COUNT, "h:p:U:wWvd", "display the total number of nodes under pgpool-II's control"},
+	{"pcp_node_info", PCP_NODE_INFO, "n:h:p:U:wWvd", "display a pgpool-II node's information"},
+	{"pcp_pool_status", PCP_POOL_STATUS, "h:p:U:wWvd", "display pgpool configuration and status"},
+	{"pcp_proc_count", PCP_PROC_COUNT, "h:p:U:wWvd", "display the list of pgpool-II child process PIDs"},
+	{"pcp_proc_info", PCP_PROC_INFO, "h:p:P:U:awWvd", "display a pgpool-II child process' information"},
+	{"pcp_promote_node", PCP_PROMOTE_NODE, "n:h:p:U:gwWvd", "promote a node as new master from pgpool-II"},
+	{"pcp_recovery_node", PCP_RECOVERY_NODE, "n:h:p:U:wWvd", "recover a node"},
+	{"pcp_stop_pgpool", PCP_STOP_PGPOOL, "m:h:p:U:wWvd", "terminate pgpool-II"},
+	{"pcp_watchdog_info", PCP_WATCHDOG_INFO, "n:h:p:U:wWvd", "display a pgpool-II watchdog's information"},
+	{NULL, UNKNOWN, NULL, NULL},
+};
+struct AppTypes *current_app_type;
 
 int
 main(int argc, char **argv)
 {
-	char* host = NULL;
-	int port = 9898;
-	char* user = NULL;
-	char* pass = NULL;
-	int nodeID = -1;
-	int processID = 0;
-	int ch;
-	char shutdown_mode = 's';
-	int	optindex;
-	int i;
-	bool all = false;
-	bool debug = false;
-	bool need_password = true;
-	bool gracefully = false;
-	bool verbose = false;
-	PCPConnInfo* pcpConn;
-	PCPResultInfo* pcpResInfo;
+	char	   *host = NULL;
+	int			port = 9898;
+	char	   *user = NULL;
+	char	   *pass = NULL;
+	int			nodeID = -1;
+	int			processID = 0;
+	int			ch;
+	char		shutdown_mode = 's';
+	int			optindex;
+	int			i;
+	bool		all = false;
+	bool		debug = false;
+	bool		need_password = true;
+	bool		gracefully = false;
+	bool		verbose = false;
+	PCPConnInfo *pcpConn;
+	PCPResultInfo *pcpResInfo;
 
 	/* here we put all the allowed long options for all utilities */
 	static struct option long_options[] = {
@@ -131,21 +131,21 @@ main(int argc, char **argv)
 		{"watchdog-id", required_argument, NULL, 'n'},
 		{NULL, 0, NULL, 0}
 	};
-	
+
 	/* Identify the utility app */
 	progname = get_progname(argv[0]);
-	for( i =0; ;i++)
+	for (i = 0;; i++)
 	{
 		current_app_type = &AllAppTypes[i];
-		if(current_app_type->app_type == UNKNOWN)
+		if (current_app_type->app_type == UNKNOWN)
 			break;
 		if (strcmp(current_app_type->app_name, progname) == 0)
 			break;
 	}
 
-	if(current_app_type->app_type == UNKNOWN)
+	if (current_app_type->app_type == UNKNOWN)
 	{
-		fprintf(stderr, "%s is a invalid PCP utility\n",progname);
+		fprintf(stderr, "%s is a invalid PCP utility\n", progname);
 		exit(1);
 	}
 
@@ -159,12 +159,13 @@ main(int argc, char **argv)
 		else if (strcmp(argv[1], "-V") == 0
 				 || strcmp(argv[1], "--version") == 0)
 		{
-			fprintf(stderr, "%s (%s) %s\n",progname,PACKAGE, VERSION);
+			fprintf(stderr, "%s (%s) %s\n", progname, PACKAGE, VERSION);
 			exit(0);
 		}
 	}
 
-	while ((ch = getopt_long(argc, argv, current_app_type->allowed_options, long_options, &optindex)) != -1) {
+	while ((ch = getopt_long(argc, argv, current_app_type->allowed_options, long_options, &optindex)) != -1)
+	{
 		switch (ch)
 		{
 			case 'd':
@@ -198,13 +199,13 @@ main(int argc, char **argv)
 						shutdown_mode = 'i';
 					else
 					{
-						fprintf(stderr, "%s: Invalid shutdown mode \"%s\", must be either \"smart\" \"immediate\" or \"fast\" \n",progname,optarg);
+						fprintf(stderr, "%s: Invalid shutdown mode \"%s\", must be either \"smart\" \"immediate\" or \"fast\" \n", progname, optarg);
 						exit(1);
 					}
 				}
 				else
 				{
-					fprintf(stderr, "Invalid argument \"%s\", Try \"%s --help\" for more information.\n",optarg,progname);
+					fprintf(stderr, "Invalid argument \"%s\", Try \"%s --help\" for more information.\n", optarg, progname);
 					exit(1);
 				}
 				break;
@@ -219,7 +220,7 @@ main(int argc, char **argv)
 				{
 					if (nodeID < 0)
 					{
-						fprintf(stderr, "%s: Invalid watchdog-id \"%s\", must be a positive number or zero for a local watchdog node\n",progname,optarg);
+						fprintf(stderr, "%s: Invalid watchdog-id \"%s\", must be a positive number or zero for a local watchdog node\n", progname, optarg);
 						exit(0);
 					}
 				}
@@ -227,7 +228,7 @@ main(int argc, char **argv)
 				{
 					if (nodeID < 0 || nodeID > MAX_NUM_BACKENDS)
 					{
-						fprintf(stderr, "%s: Invalid node-id \"%s\", must be between 0 and %d\n",progname,optarg,MAX_NUM_BACKENDS);
+						fprintf(stderr, "%s: Invalid node-id \"%s\", must be between 0 and %d\n", progname, optarg, MAX_NUM_BACKENDS);
 						exit(0);
 					}
 				}
@@ -237,16 +238,16 @@ main(int argc, char **argv)
 				port = atoi(optarg);
 				if (port <= 1024 || port > 65535)
 				{
-					fprintf(stderr, "%s: Invalid port number \"%s\", must be between 1024 and 65535\n",progname,optarg);
+					fprintf(stderr, "%s: Invalid port number \"%s\", must be between 1024 and 65535\n", progname, optarg);
 					exit(0);
 				}
 				break;
 
-			case 'P': /* PID */
+			case 'P':			/* PID */
 				processID = atoi(optarg);
-				if (processID <= 0 )
+				if (processID <= 0)
 				{
-					fprintf(stderr, "%s: Invalid process-id \"%s\", must be greater than 0\n",progname,optarg);
+					fprintf(stderr, "%s: Invalid process-id \"%s\", must be greater than 0\n", progname, optarg);
 					exit(0);
 				}
 				break;
@@ -261,10 +262,11 @@ main(int argc, char **argv)
 
 			case '?':
 			default:
+
 				/*
 				 * getopt_long whould already have emitted a complaint
 				 */
-				fprintf(stderr, "Try \"%s --help\" for more information.\n\n",progname);
+				fprintf(stderr, "Try \"%s --help\" for more information.\n\n", progname);
 				exit(1);
 		}
 	}
@@ -277,18 +279,18 @@ main(int argc, char **argv)
 		if (current_app_type->app_type == PCP_PROC_INFO && processID <= 0)
 		{
 			processID = atoi(argv[optind]);
-			if (processID <= 0 )
+			if (processID <= 0)
 			{
-				fprintf(stderr, "%s: Invalid process-id \"%s\", must be greater than 0\n",progname,optarg);
+				fprintf(stderr, "%s: Invalid process-id \"%s\", must be greater than 0\n", progname, optarg);
 				exit(0);
 			}
 		}
 		else if (current_app_type->app_type == PCP_WATCHDOG_INFO && nodeID < 0)
 		{
 			nodeID = atoi(argv[optind]);
-			if (nodeID < 0 )
+			if (nodeID < 0)
 			{
-				fprintf(stderr, "%s: Invalid watchdog-id \"%s\", must be a positive number or zero for local watchdog node\n",progname,optarg);
+				fprintf(stderr, "%s: Invalid watchdog-id \"%s\", must be a positive number or zero for local watchdog node\n", progname, optarg);
 				exit(0);
 			}
 		}
@@ -297,7 +299,7 @@ main(int argc, char **argv)
 			nodeID = atoi(argv[optind]);
 			if (nodeID < 0 || nodeID > MAX_NUM_BACKENDS)
 			{
-				fprintf(stderr, "%s: Invalid node-id \"%s\", must be between 0 and %d\n",progname,optarg,MAX_NUM_BACKENDS);
+				fprintf(stderr, "%s: Invalid node-id \"%s\", must be between 0 and %d\n", progname, optarg, MAX_NUM_BACKENDS);
 				exit(0);
 			}
 		}
@@ -308,12 +310,12 @@ main(int argc, char **argv)
 		optind++;
 	}
 
-	if(nodeID < 0)
+	if (nodeID < 0)
 	{
 		if (app_require_nodeID())
 		{
-			fprintf(stderr, "%s: missing node-id\n",progname);
-			fprintf(stderr, "Try \"%s --help\" for more information.\n\n",progname);
+			fprintf(stderr, "%s: missing node-id\n", progname);
+			fprintf(stderr, "Try \"%s --help\" for more information.\n\n", progname);
 			exit(1);
 		}
 		else if (current_app_type->app_type == PCP_WATCHDOG_INFO)
@@ -329,10 +331,10 @@ main(int argc, char **argv)
 		need_password = false;
 	}
 
-	pcpConn = pcp_connect(host, port, user, pass, debug?stdout:NULL);
-	if(PCPConnectionStatus(pcpConn) != PCP_CONNECTION_OK)
+	pcpConn = pcp_connect(host, port, user, pass, debug ? stdout : NULL);
+	if (PCPConnectionStatus(pcpConn) != PCP_CONNECTION_OK)
 	{
-		fprintf(stderr, "%s\n",pcp_get_last_error(pcpConn)?pcp_get_last_error(pcpConn):"Unknown Error");
+		fprintf(stderr, "%s\n", pcp_get_last_error(pcpConn) ? pcp_get_last_error(pcpConn) : "Unknown Error");
 		exit(1);
 	}
 
@@ -341,15 +343,15 @@ main(int argc, char **argv)
 	 */
 	if (current_app_type->app_type == PCP_ATTACH_NODE)
 	{
-		pcpResInfo = pcp_attach_node(pcpConn,nodeID);
+		pcpResInfo = pcp_attach_node(pcpConn, nodeID);
 	}
 
 	else if (current_app_type->app_type == PCP_DETACH_NODE)
 	{
 		if (gracefully)
-			pcpResInfo = pcp_detach_node_gracefully(pcpConn,nodeID);
+			pcpResInfo = pcp_detach_node_gracefully(pcpConn, nodeID);
 		else
-			pcpResInfo = pcp_detach_node(pcpConn,nodeID);
+			pcpResInfo = pcp_detach_node(pcpConn, nodeID);
 	}
 
 	else if (current_app_type->app_type == PCP_NODE_COUNT)
@@ -359,7 +361,7 @@ main(int argc, char **argv)
 
 	else if (current_app_type->app_type == PCP_NODE_INFO)
 	{
-		pcpResInfo = pcp_node_info(pcpConn,nodeID);
+		pcpResInfo = pcp_node_info(pcpConn, nodeID);
 	}
 
 	else if (current_app_type->app_type == PCP_POOL_STATUS)
@@ -380,9 +382,9 @@ main(int argc, char **argv)
 	else if (current_app_type->app_type == PCP_PROMOTE_NODE)
 	{
 		if (gracefully)
-			pcpResInfo = pcp_promote_node_gracefully(pcpConn,nodeID);
+			pcpResInfo = pcp_promote_node_gracefully(pcpConn, nodeID);
 		else
-			pcpResInfo = pcp_promote_node(pcpConn,nodeID);
+			pcpResInfo = pcp_promote_node(pcpConn, nodeID);
 	}
 
 	else if (current_app_type->app_type == PCP_RECOVERY_NODE)
@@ -397,25 +399,25 @@ main(int argc, char **argv)
 
 	else if (current_app_type->app_type == PCP_WATCHDOG_INFO)
 	{
-		pcpResInfo = pcp_watchdog_info(pcpConn,nodeID);
+		pcpResInfo = pcp_watchdog_info(pcpConn, nodeID);
 	}
 
 	else
 	{
 		/* should never happen */
-		fprintf(stderr,"%s: Invalid pcp process\n",progname);
+		fprintf(stderr, "%s: Invalid pcp process\n", progname);
 		goto DISCONNECT_AND_EXIT;
 	}
 
-	if(pcpResInfo == NULL || PCPResultStatus(pcpResInfo) != PCP_RES_COMMAND_OK)
+	if (pcpResInfo == NULL || PCPResultStatus(pcpResInfo) != PCP_RES_COMMAND_OK)
 	{
-		fprintf(stderr, "%s\n",pcp_get_last_error(pcpConn)?pcp_get_last_error(pcpConn):"Unknown Error");
+		fprintf(stderr, "%s\n", pcp_get_last_error(pcpConn) ? pcp_get_last_error(pcpConn) : "Unknown Error");
 		goto DISCONNECT_AND_EXIT;
 	}
 
 	if (pcp_result_is_empty(pcpResInfo))
 	{
-		fprintf(stdout,"%s -- Command Successful\n",progname);
+		fprintf(stdout, "%s -- Command Successful\n", progname);
 	}
 	else
 	{
@@ -447,9 +449,9 @@ DISCONNECT_AND_EXIT:
 }
 
 static void
-output_nodecount_result(PCPResultInfo* pcpResInfo, bool verbose)
+output_nodecount_result(PCPResultInfo * pcpResInfo, bool verbose)
 {
-	if(verbose)
+	if (verbose)
 	{
 		printf("Node Count\n");
 		printf("____________\n");
@@ -460,54 +462,66 @@ output_nodecount_result(PCPResultInfo* pcpResInfo, bool verbose)
 }
 
 static void
-output_nodeinfo_result(PCPResultInfo* pcpResInfo, bool verbose)
+output_nodeinfo_result(PCPResultInfo * pcpResInfo, bool verbose)
 {
-	BackendInfo *backend_info = (BackendInfo *) pcp_get_binary_data(pcpResInfo,0);
+	BackendInfo *backend_info = (BackendInfo *) pcp_get_binary_data(pcpResInfo, 0);
+	char		last_status_change[20];
+	struct tm	tm;
+
+	localtime_r(&backend_info->status_changed_time, &tm);
+	strftime(last_status_change, sizeof(last_status_change), "%F %T", &tm);
 
 	if (verbose)
 	{
-		printf("Hostname   : %s\nPort       : %d\nStatus     : %d\nWeight     : %f\nStatus Name: %s\nRole       : %s\n",
+		printf("Hostname          : %s\nPort              : %d\nStatus            : %d\nWeight            : %f\nStatus Name       : %s\nRole              : %s\nReplication Delay : %lu\nLast Status Change: %s\n",
 			   backend_info->backend_hostname,
 			   backend_info->backend_port,
 			   backend_info->backend_status,
-			   backend_info->backend_weight/RAND_MAX,
+			   backend_info->backend_weight / RAND_MAX,
 			   backend_status_to_string(backend_info),
-			   role_to_str(backend_info->role));
-	} else {
-		printf("%s %d %d %f %s %s\n",
+			   role_to_str(backend_info->role),
+			   backend_info->standby_delay,
+			   last_status_change);
+	}
+	else
+	{
+		printf("%s %d %d %f %s %s %lu %s\n",
 			   backend_info->backend_hostname,
 			   backend_info->backend_port,
 			   backend_info->backend_status,
-			   backend_info->backend_weight/RAND_MAX,
+			   backend_info->backend_weight / RAND_MAX,
 			   backend_status_to_string(backend_info),
-			   role_to_str(backend_info->role));
+			   role_to_str(backend_info->role),
+			   backend_info->standby_delay,
+			   last_status_change);
 	}
 }
 
 static void
-output_poolstatus_result(PCPResultInfo* pcpResInfo, bool verbose)
+output_poolstatus_result(PCPResultInfo * pcpResInfo, bool verbose)
 {
 	POOL_REPORT_CONFIG *status;
-	int i;
-	int array_size = pcp_result_slot_count(pcpResInfo);
+	int			i;
+	int			array_size = pcp_result_slot_count(pcpResInfo);
 
-	if(verbose)
+	if (verbose)
 	{
-		for (i=0; i < array_size; i++)
+		for (i = 0; i < array_size; i++)
 		{
-			status = (POOL_REPORT_CONFIG *)pcp_get_binary_data(pcpResInfo, i);
-			printf("Name [%3d]:\t%s\n",i,status?status->name:"NULL");
-			printf("Value:      \t%s\n",status?status->value:"NULL");
-			printf("Description:\t%s\n\n",status?status->desc:"NULL");
+			status = (POOL_REPORT_CONFIG *) pcp_get_binary_data(pcpResInfo, i);
+			printf("Name [%3d]:\t%s\n", i, status ? status->name : "NULL");
+			printf("Value:      \t%s\n", status ? status->value : "NULL");
+			printf("Description:\t%s\n\n", status ? status->desc : "NULL");
 		}
 	}
 	else
 	{
-		for (i=0; i < array_size; i++) {
-			status = (POOL_REPORT_CONFIG *)pcp_get_binary_data(pcpResInfo, i);
-			if(status == NULL)
+		for (i = 0; i < array_size; i++)
+		{
+			status = (POOL_REPORT_CONFIG *) pcp_get_binary_data(pcpResInfo, i);
+			if (status == NULL)
 			{
-				printf("****Data at %d slot is NULL\n",i);
+				printf("****Data at %d slot is NULL\n", i);
 				continue;
 			}
 			printf("name : %s\nvalue: %s\ndesc : %s\n\n", status->name, status->value, status->desc);
@@ -516,19 +530,19 @@ output_poolstatus_result(PCPResultInfo* pcpResInfo, bool verbose)
 }
 
 static void
-output_proccount_result(PCPResultInfo* pcpResInfo, bool verbose)
+output_proccount_result(PCPResultInfo * pcpResInfo, bool verbose)
 {
-	int i;
-	int process_count = pcp_get_data_length(pcpResInfo, 0) / sizeof(int);
-	int *process_list = (int *)pcp_get_binary_data(pcpResInfo, 0);
+	int			i;
+	int			process_count = pcp_get_data_length(pcpResInfo, 0) / sizeof(int);
+	int		   *process_list = (int *) pcp_get_binary_data(pcpResInfo, 0);
 
 	if (verbose)
 	{
 		printf("No \t | \t PID\n");
 		printf("_____________________\n");
 		for (i = 0; i < process_count; i++)
-			printf("%d \t | \t %d\n", i,process_list[i]);
-		printf("\nTotal Processes:%d\n",process_count);
+			printf("%d \t | \t %d\n", i, process_list[i]);
+		printf("\nTotal Processes:%d\n", process_count);
 	}
 	else
 	{
@@ -539,18 +553,18 @@ output_proccount_result(PCPResultInfo* pcpResInfo, bool verbose)
 }
 
 static void
-output_procinfo_result(PCPResultInfo* pcpResInfo, bool all, bool verbose)
+output_procinfo_result(PCPResultInfo * pcpResInfo, bool all, bool verbose)
 {
-	bool printed = false;
-	int i;
-	char * frmt;
-	char strcreatetime[128];
-	char strstarttime[128];
-	int array_size = pcp_result_slot_count(pcpResInfo);
+	bool		printed = false;
+	int			i;
+	char	   *frmt;
+	char		strcreatetime[128];
+	char		strstarttime[128];
+	int			array_size = pcp_result_slot_count(pcpResInfo);
+
 	if (verbose)
 	{
-		if (all)
-			frmt =	"Database     : %s\n"
+		frmt = "Database     : %s\n"
 			"Username     : %s\n"
 			"Start time   : %s\n"
 			"Creation time: %s\n"
@@ -561,41 +575,29 @@ output_procinfo_result(PCPResultInfo* pcpResInfo, bool all, bool verbose)
 			"Connected    : %d\n"
 			"PID          : %d\n"
 			"Backend ID   : %d\n";
-		else
-			frmt =	"Database     : %s\n"
-			"Username     : %s\n"
-			"Start time   : %s\n"
-			"Creation time: %s\n"
-			"Major        : %d\n"
-			"Minor        : %d\n"
-			"Counter      : %d\n"
-			"Backend PID  : %d\n"
-			"Connected    : %d\n";
 	}
 	else
 	{
-		if (all)
-			frmt = "%s %s %s %s %d %d %d %d %d %d %d\n";
-		else
-			frmt = "%s %s %s %s %d %d %d %d %d\n";
+		frmt = "%s %s %s %s %d %d %d %d %d %d %d\n";
 	}
 
 	for (i = 0; i < array_size; i++)
 	{
 
-		ProcessInfo *process_info = (ProcessInfo*) pcp_get_binary_data(pcpResInfo, i);
-		if(process_info == NULL)
+		ProcessInfo *process_info = (ProcessInfo *) pcp_get_binary_data(pcpResInfo, i);
+
+		if (process_info == NULL)
 			break;
 		if ((!all) && (process_info->connection_info->database[0] == '\0'))
 			continue;
 		printed = true;
 		*strcreatetime = *strstarttime = '\0';
-		
+
 		if (process_info->start_time)
 			strftime(strstarttime, 128, "%Y-%m-%d %H:%M:%S", localtime(&process_info->start_time));
 		if (process_info->connection_info->create_time)
 			strftime(strcreatetime, 128, "%Y-%m-%d %H:%M:%S", localtime(&process_info->connection_info->create_time));
-		
+
 		printf(frmt,
 			   process_info->connection_info->database,
 			   process_info->connection_info->user,
@@ -609,18 +611,20 @@ output_procinfo_result(PCPResultInfo* pcpResInfo, bool all, bool verbose)
 			   process_info->pid,
 			   process_info->connection_info->backend_id);
 	}
-	if(printed == false)
+	if (printed == false)
 		printf("No process information available\n\n");
 }
 
 static void
-output_watchdog_info_result(PCPResultInfo* pcpResInfo, bool verbose)
+output_watchdog_info_result(PCPResultInfo * pcpResInfo, bool verbose)
 {
-	int i;
-	PCPWDClusterInfo *cluster = (PCPWDClusterInfo *)pcp_get_binary_data(pcpResInfo,0);
+	int			i;
+	PCPWDClusterInfo *cluster = (PCPWDClusterInfo *) pcp_get_binary_data(pcpResInfo, 0);
+
 	if (verbose)
 	{
-		char* quorumStatus;
+		char	   *quorumStatus;
+
 		if (cluster->quorumStatus == 0)
 			quorumStatus = "QUORUM IS ON THE EDGE";
 		else if (cluster->quorumStatus == 1)
@@ -633,39 +637,41 @@ output_watchdog_info_result(PCPResultInfo* pcpResInfo, bool verbose)
 			quorumStatus = "UNKNOWN";
 
 		printf("Watchdog Cluster Information \n");
-		printf("Total Nodes          : %d\n",cluster->remoteNodeCount +1);
-		printf("Remote Nodes         : %d\n",cluster->remoteNodeCount);
-		printf("Quorum state         : %s\n",quorumStatus);
-		printf("Alive Remote Nodes   : %d\n",cluster->aliveNodeCount);
-		printf("Local node escalation: %s\n",cluster->escalated ? "YES" : "NO");
-		printf("Master Node Name     : %s\n",cluster->masterNodeName);
-		printf("Master Host Name     : %s\n\n",cluster->masterHostName);
+		printf("Total Nodes          : %d\n", cluster->remoteNodeCount + 1);
+		printf("Remote Nodes         : %d\n", cluster->remoteNodeCount);
+		printf("Quorum state         : %s\n", quorumStatus);
+		printf("Alive Remote Nodes   : %d\n", cluster->aliveNodeCount);
+		printf("Local node escalation: %s\n", cluster->escalated ? "YES" : "NO");
+		printf("Master Node Name     : %s\n", cluster->masterNodeName);
+		printf("Master Host Name     : %s\n\n", cluster->masterHostName);
 
 		printf("Watchdog Node Information \n");
-		for (i=0; i< cluster->nodeCount; i++)
+		for (i = 0; i < cluster->nodeCount; i++)
 		{
-			PCPWDNodeInfo* watchdog_info = &cluster->nodeList[i];
-			printf("Node Name      : %s\n",watchdog_info->nodeName);
-			printf("Host Name      : %s\n",watchdog_info->hostName);
-			printf("Delegate IP    : %s\n",watchdog_info->delegate_ip);
-			printf("Pgpool port    : %d\n",watchdog_info->pgpool_port);
-			printf("Watchdog port  : %d\n",watchdog_info->wd_port);
-			printf("Node priority  : %d\n",watchdog_info->wd_priority);
-			printf("Status         : %d\n",watchdog_info->state);
-			printf("Status Name    : %s\n\n",watchdog_info->stateName);
+			PCPWDNodeInfo *watchdog_info = &cluster->nodeList[i];
+
+			printf("Node Name      : %s\n", watchdog_info->nodeName);
+			printf("Host Name      : %s\n", watchdog_info->hostName);
+			printf("Delegate IP    : %s\n", watchdog_info->delegate_ip);
+			printf("Pgpool port    : %d\n", watchdog_info->pgpool_port);
+			printf("Watchdog port  : %d\n", watchdog_info->wd_port);
+			printf("Node priority  : %d\n", watchdog_info->wd_priority);
+			printf("Status         : %d\n", watchdog_info->state);
+			printf("Status Name    : %s\n\n", watchdog_info->stateName);
 		}
 	}
 	else
 	{
 		printf("%d %s %s %s\n\n",
-			   cluster->remoteNodeCount +1,
-			   cluster->escalated?"YES":"NO",
+			   cluster->remoteNodeCount + 1,
+			   cluster->escalated ? "YES" : "NO",
 			   cluster->masterNodeName,
 			   cluster->masterHostName);
 
-		for (i=0; i< cluster->nodeCount; i++)
+		for (i = 0; i < cluster->nodeCount; i++)
 		{
-			PCPWDNodeInfo* watchdog_info = &cluster->nodeList[i];
+			PCPWDNodeInfo *watchdog_info = &cluster->nodeList[i];
+
 			printf("%s %s %d %d %d %s\n",
 				   watchdog_info->nodeName,
 				   watchdog_info->hostName,
@@ -681,25 +687,26 @@ output_watchdog_info_result(PCPResultInfo* pcpResInfo, bool verbose)
 static inline bool
 app_require_nodeID(void)
 {
-	return(current_app_type->app_type == PCP_ATTACH_NODE  ||
-		   current_app_type->app_type == PCP_DETACH_NODE  ||
-		   current_app_type->app_type == PCP_NODE_INFO    ||
-		   current_app_type->app_type == PCP_PROMOTE_NODE ||
-		   current_app_type->app_type == PCP_RECOVERY_NODE);
+	return (current_app_type->app_type == PCP_ATTACH_NODE ||
+			current_app_type->app_type == PCP_DETACH_NODE ||
+			current_app_type->app_type == PCP_NODE_INFO ||
+			current_app_type->app_type == PCP_PROMOTE_NODE ||
+			current_app_type->app_type == PCP_RECOVERY_NODE);
 }
 
 
 static void
 usage(void)
 {
-	fprintf(stderr, "%s - %s\n",progname,current_app_type->description);
+	fprintf(stderr, "%s - %s\n", progname, current_app_type->description);
 	fprintf(stderr, "Usage:\n");
-	fprintf(stderr, "%s [OPTION...] %s\n",progname,
-			app_require_nodeID()?"[node-id]":
-			(current_app_type->app_type == PCP_WATCHDOG_INFO)?"[watchdog-id]":
-			(current_app_type->app_type == PCP_PROC_INFO)?"[process-id]":"");
+	fprintf(stderr, "%s [OPTION...] %s\n", progname,
+			app_require_nodeID() ? "[node-id]" :
+			(current_app_type->app_type == PCP_WATCHDOG_INFO) ? "[watchdog-id]" :
+			(current_app_type->app_type == PCP_PROC_INFO) ? "[process-id]" : "");
 
 	fprintf(stderr, "Options:\n");
+
 	/*
 	 * print the command options
 	 */
@@ -708,6 +715,7 @@ usage(void)
 	fprintf(stderr, "  -p, --port=PORT        PCP port number\n");
 	fprintf(stderr, "  -w, --no-password      never prompt for password\n");
 	fprintf(stderr, "  -W, --password         force password prompt (should happen automatically)\n");
+
 	/*
 	 * Now the options not available for all utilities
 	 */
@@ -752,14 +760,14 @@ const char *
 get_progname(const char *argv0)
 {
 	const char *nodir_name;
-	char       *progname;
-	
+	char	   *progname;
+
 	nodir_name = last_dir_separator(argv0);
 	if (nodir_name)
 		nodir_name++;
 	else
 		nodir_name = argv0;
-	
+
 	/*
 	 * Make a copy in case argv[0] is modified by ps_status. Leaks memory, but
 	 * called only once.
@@ -768,9 +776,9 @@ get_progname(const char *argv0)
 	if (progname == NULL)
 	{
 		fprintf(stderr, "%s: out of memory\n", nodir_name);
-		exit(1);                                /* This could exit the postmaster */
+		exit(1);				/* This could exit the postmaster */
 	}
-	
+
 	return progname;
 }
 
@@ -778,11 +786,13 @@ get_progname(const char *argv0)
  * Translate the BACKEND_STATUS enum value to string.
  * the function returns the constant string so should not be freed
  */
-static char* backend_status_to_string(BackendInfo *bi)
+static char *
+backend_status_to_string(BackendInfo * bi)
 {
-	char *statusName;
+	char	   *statusName;
 
-	switch (bi->backend_status) {
+	switch (bi->backend_status)
+	{
 
 		case CON_UNUSED:
 			statusName = BACKEND_STATUS_CON_UNUSED;
@@ -797,12 +807,12 @@ static char* backend_status_to_string(BackendInfo *bi)
 			break;
 
 		case CON_DOWN:
-		{
-			if (bi->quarantine)
-				statusName = BACKEND_STATUS_QUARANTINE;
-			else
-				statusName = BACKEND_STATUS_CON_DOWN;
-		}
+			{
+				if (bi->quarantine)
+					statusName = BACKEND_STATUS_QUARANTINE;
+				else
+					statusName = BACKEND_STATUS_CON_DOWN;
+			}
 			break;
 
 		default:
@@ -813,9 +823,11 @@ static char* backend_status_to_string(BackendInfo *bi)
 }
 
 /* Convert enum role to string */
-char *role_to_str(SERVER_ROLE role)
+char *
+role_to_str(SERVER_ROLE role)
 {
 	static char *role_str[] = {"master", "slave", "primary", "standby"};
+
 	if (role < ROLE_MASTER || role > ROLE_STANDBY)
 		return "unknown";
 	return role_str[role];
